@@ -61,9 +61,18 @@ class Horde_Crypt_Pgp_Keyserver
     public function __construct($pgp, array $params = array())
     {
         $this->_pgp = $pgp;
-        $this->_http = (isset($params['http']) && ($params['http'] instanceof Horde_Http_Client))
-            ? $params['http']
-            : new Horde_Http_Client();
+        if (isset($params['http'])) {
+            if (!($params['http'] instanceof Horde_Http_Client)) {
+                throw new InvalidArgumentException('Argument is not a Horde_Http_Client instance');
+            }
+            $this->_http = $params['http'];
+        } else {
+            $this->_http = new Horde_Http_Client();
+        }
+        /* There is a broken key server software that returns HTML content
+         * instead of plain text on arbitrary criteria. A User-Agent header is
+         * one of those. */
+        $this->_http->{'request.userAgent'} = '';
         $this->_keyserver = isset($params['keyserver'])
             ? $params['keyserver']
             : 'http://pool.sks-keyservers.net';
@@ -157,10 +166,25 @@ class Horde_Crypt_Pgp_Keyserver
             'search' => $address
         ));
 
-        try {
-            $output = $this->_http->get($url)->getBody();
-        } catch (Horde_Http_Exception $e) {
-            throw new Horde_Crypt_Exception($e);
+        // Some keyservers are broken, third time's a charm.
+        $output = null;
+        for ($i = 0; $i < 3; $i++) {
+            try {
+                $response = $this->_http->get($url);
+                // Some keyservers return HTML, try again.
+                if (strpos($response->getHeader('Content-Type'), 'text/plain') !== 0) {
+                    continue;
+                }
+                $output = $response->getBody();
+            } catch (Horde_Http_Exception $e) {
+                throw new Horde_Crypt_Exception($e);
+            }
+        }
+
+        if (!$output) {
+            throw new Horde_Crypt_Exception(
+                Horde_Crypt_Translation::t("Could not obtain public key from the keyserver.")
+            );
         }
 
         if (strpos($output, '-----BEGIN PGP PUBLIC KEY BLOCK') !== false) {
