@@ -159,7 +159,7 @@ class Horde_Crypt_Pgp_Parse
         $new_part = new Horde_Mime_Part();
         $new_part->setType('multipart/mixed');
 
-        foreach ($parts as $val) {
+        while (list(,$val) = each($parts)) {
             switch ($val['type']) {
             case self::ARMOR_TEXT:
                 $part = new Horde_Mime_Part();
@@ -198,7 +198,7 @@ class Horde_Crypt_Pgp_Parse
                 break;
 
             case self::ARMOR_SIGNED_MESSAGE:
-                if (($sig = current($parts)) &&
+                if ((list(,$sig) = each($parts)) &&
                     ($sig['type'] == self::ARMOR_SIGNATURE)) {
                     $part = new Horde_Mime_Part();
                     $part->setType('multipart/signed');
